import * as ec2 from "aws-cdk-lib/aws-ec2";
import * as iam from "aws-cdk-lib/aws-iam";
import * as mwaa from "aws-cdk-lib/aws-mwaa";
import * as s3 from "aws-cdk-lib/aws-s3";
import * as s3deploy from "aws-cdk-lib/aws-s3-deployment";
import { Construct } from "constructs";
export interface MWAAEnvironmentProps extends mwaa.CfnEnvironmentProps {
    /**
     * Log level for DagProcessing
     */
    readonly dagProcessingLogs?: string;
    /**
     * Log level for SchedulerLogs
     */
    readonly schedulerLogsLevel?: string;
    /**
     * Log level for TaskLogs
     */
    readonly taskLogsLevel?: string;
    /**
     * Log level for WorkerLogs
     */
    readonly workerLogsLevel?: string;
    /**
     * Log level for WebserverLogs
     */
    readonly webserverLogsLevel?: string;
    /**
     * Existing vpc id
     */
    readonly vpcId?: string;
    /**
     * The IP range (CIDR notation) for this VPC
     */
    readonly vpcCidr?: string;
    /**
     * S3 Bucket
     */
    readonly s3Bucket?: s3.IBucket;
    /**
     * File(s) to be uploaded to dags location in s3 bucket.
     */
    readonly dagFiles?: string[];
    /**
     * Requirements file to be uploaded to plugin path in S3. 'requirementsS3Path' must be specified as well.
     */
    readonly requirementsFile?: string;
    /**
     * Plugin file to be uploaded to plugin path in S3. 'pluginsS3Path' must be specified as well.
     */
    readonly pluginFile?: string;
    /**
     * Additional policy statements to add to the airflow execution role
     */
    readonly additionalPolicyStatements?: iam.PolicyStatement[];
}
export declare class MWAAEnvironment extends Construct {
    readonly dagProcessingLogs: string;
    readonly schedulerLogsLevel: string;
    readonly taskLogsLevel: string;
    readonly workerLogsLevel: string;
    readonly webserverLogsLevel: string;
    readonly vpc: ec2.IVpc;
    readonly s3Bucket: s3.IBucket;
    readonly mwaaEnvironment: mwaa.CfnEnvironment;
    readonly dagS3Path: string;
    readonly pluginFile?: s3deploy.BucketDeployment;
    constructor(scope: Construct, id: string, props: MWAAEnvironmentProps);
    createVpc(scope: Construct, environmentName: string, vpcCidr: string): ec2.IVpc;
}
