import * as cdk from "aws-cdk-lib";
import * as events from "aws-cdk-lib/aws-events";
import * as lambda from "aws-cdk-lib/aws-lambda";
import * as sfn from "aws-cdk-lib/aws-stepfunctions";
import { Construct } from "constructs";
import { StateMachineStage, StateMachineStageProps } from "../pipelines/stage";
/**
 * Properties of the MWAA Trigger Dags stage.
 */
export interface MWAATriggerDagsStageProps extends StateMachineStageProps {
    /**
     * Name of airflow environment.
     */
    readonly mwaaEnvironmentName: string;
    /**
     * Name of dag(s) to trigger.
     */
    readonly dags?: string[];
    /**
     * Path to array of dag id's to check.
     */
    readonly dagPath?: string;
    /**
     * Time to wait between execution status checks.
     * @default aws_cdk.Duration.seconds(15)
     */
    readonly statusCheckPeriod?: cdk.Duration;
}
export interface MWAALambdasResult {
    readonly triggerLambda: lambda.Function;
    readonly statusLambda: lambda.Function;
}
/**
 * Stage that contains a step function that runs a Managed Apache Airflow (MWAA) dag or set of dags .
 */
export declare class MWAATriggerDagsStage extends StateMachineStage {
    readonly targets?: events.IRuleTarget[];
    readonly eventPattern?: events.EventPattern;
    readonly stateMachine: sfn.StateMachine;
    readonly mwaaEnvironmentName: string;
    /**
     * Constructs MWAATriggerDagsStage.
     * @param scope Scope within which this construct is defined.
     * @param id Identifier of the stage.
     * @param props Properties for the stage.
     */
    constructor(scope: Construct, id: string, props: MWAATriggerDagsStageProps);
    private buildLambdas;
}
